*[HTML]: Hyper Text Markup Language
*[W3C]: World Wide Web Consortium
*[ISO]: International Organization for Standardization
*[bit]: atomic unit of information in a computer system
*[byte]: sequence of 8 bits
*[nibble]: half a byte, which can be represented by a single hexadecimal digit
*[data]: ordered sequence of bits
*[file]: stored data with a known number of bits and a filename
*[stream]: data in transit with a known or unknown number of bits
*[digital content]: manifestation of content in form of data structured according to a set of rules
*[content identifier]: identifier whose referent is content
*[content format]: set of rules used to structure digital content
*[content]: information organized to provide value to a user
*[seed metadata]: initial metadata used as input to a hash function
*[metadata]: data that defines and describes other data
*[media type]: two-part identifier specifying the nature of the referenced data
*[digital asset]: file or stream encoded in conformance with a specific content format
*[referent]: that which is identified
*[identifier system]: system to enable the provision of identifiers for a given category of referents
*[content-dependent identifier]: content identifier whose data depends on the digital content that it identifies
*[identifier]: sequence of characters that uniquely denotes a referent
*[content recognitions system]: system whose primary purpose is to recognise digital content on a granular level
*[hash algorithm]: deterministic algorithm that produces fixed-length data from an input of arbitrary-length data
*[algorithm]: set of instructions
*[cryptographic hash function]: computationally efficient function mapping binary strings of arbitrary length to binary strings of fixed length, such that it is computationally infeasible to find two distinct values that hash into a common value
*[similarity hash]: hash that preserves correlations between inputs to the hash algorithm
*[hash]: result of processing data with a hash algorithm
*[CDC]: content defined chunking
*[content defined chunking]: method to split data into variable length chunks based on internal features such that chunk boundaries are mor resistant to byte shifting
*[actor]: human or non-human (hardware or software) entity that interacts with a system
*[merkle tree]: tree data structure in which every leaf node is labelled with the hash value of a data element and every non-leaf node is labelled with the hash value of the labels of its child nodes
*[merkle root]: roor node of a merkle tree
*[ISCC-SUM]: ISCC based checkum and simlilarity hash
*[ISCC processor]: application that generates ISCCs for digital content
*[ISCC]: International Standard Content Code
*[plain text]: data with a known text encoding that can be transcoded to Unicode
*[whitepace]: The nondisplaying formatting characters such as spaces, tabs, etc., that are embedded within a block of free text.
